#!/bin/bash
echo "========================================================="
echo "HeatBooster firmware updater"
echo "(c) 2022 SDR Engineering - onderdeel van Solardoctor B.V."
echo "========================================================="
echo ""
echo ""

hash python3 2>/dev/null || {
  echo "Error: Python3 not found. Install Python3 first."
  exit 1;
}

hash esptool.py 2>/dev/null || {
    echo "Esptool not installed, preparing Python environment now."
    echo "Creating venv for esptool..."
    python3 -m venv esptool_env

    echo "Activating venv..."
    source ./esptool_env/bin/activate

    hash pip 2>/dev/null || {
      echo "Installing pip..."
      python3 -m ensurepip --upgrade
    }

    hash esptool.py 2>/dev/null || {
      echo "Installing esptool..."
      pip install esptool
    }
}

hash esptool.py 2>/dev/null || {
  echo "Error: esptool.py not found. Probably something went wrong with the venv. Install using 'pip install esptool' in venv esptool_env."
  deactivate
  exit 1;
}


echo ""
echo "Esptool ready!"
echo ""
echo ""
echo "------------"
echo "QUICK MANUAL"
echo "------------"
echo "Before continuing, make sure there are no cables connected to the HeatBooster."
echo "1) Do the following in case your HeatBooster has a PROG-button on the PCB, otherwise skip to step 2 (ie. do not connect 12V in this case)."
echo "     - Hold the PROG-button while connecting the 12V adapter to the HeatBooster."
echo "     - If the LED on the board is lit in very dim green, release the PROG-button."
echo "       Note: the LED should not be blinking or bright green, in that case, try step 1 again."
echo "2) Connect the HeatBooster with your computer via USB, and press [ENTER] to start flashing."
echo "3) The updater will search for the correct COM-port, and might try them all. Just have some patience."
echo ""
echo "Warning: updating the firmware will erase the configuration of the module."
echo "Warning: this firmware updater is only compatible with board version R05 and later"
echo ""
echo "------------"
echo ""

read -p "Press [ENTER] to continue..." </dev/tty

echo "Updating firmware..."
esptool.py --chip esp32c3 --baud 921600 --port-filter vid=0x303A --before usb_reset write_flash 0x0000 ./firmware.bin

retval=$?

deactivate
rm -rf ./esptool_env

if [ $retval -eq 0 ];
then
    echo "";
    echo "Flashing succesful.";
    exit 0;
else
    echo "";
    echo "An error occured! Flashing failed.";
    exit 1;
fi

exit 1;